microspeclib.datatypes.command module
======================================

.. automodule:: microspeclib.datatypes.command
   :members:
   :undoc-members:
   :exclude-members: command_id, name, const, variables, sizes, repeat
